@@ -99,7 +99,20 @@ def validate_lists_of_values(value: str):
 #
 #_______________________________________________________________________________________________________________________
 class ARMA(ArmaProcess):
+    """
+    A class to represent stationary ARMA processes
+    """
+
     def __init__(self, c=0, phi=None, theta=None, sigma2=1.0, nobs=120):
+        """
+        Making  a new ARMA object to represent $y_t = c + phi y_{t-lags} + e_t + theta e_{t- lags}$
+
+        :param c:  float, intercept
+        :param phi: list-like, autorregresive coefficients
+        :param theta: list-like, moving average coefficients
+        :param sigma2: float, positive, variance of the error term
+        :param nobs: int, number of periods for simulated sample (if requested)
+        """
         if type(phi) is np.ndarray:
             ar = np.r_[1, -phi]  # add zero-lag and negate
         elif phi in (None, 0, ''):
@@ -130,10 +143,20 @@ class ARMA(ArmaProcess):
 
     @property
     def mean(self):
+        """
+        Mean of the process (if stationary)
+        :return:
+        float: mean of the process
+        """
         return self.c / self.Phi(1) if self.isstationary else np.nan
 
     @property
     def variance(self):
+        """
+        Variance of the process (if stationary)
+        :return:
+        float, variance of the process
+        """
         frequencies, weights = qnwsimp(121, 0, np.pi)
         sw = self.periodogram(frequencies)
         return 2* weights.dot(sw)
@@ -164,6 +187,11 @@ class ARMA(ArmaProcess):
         return y
 
     def sample(self, n=101):
+        """
+
+        :param n:
+        :return:
+        """
         e = self.__simulate_shocks(n + self.q)
         ma = self.__simulate_MA(e)
         self.simulated_data = pd.Series(self.__simulate_AR(ma))
