@@ -132,8 +132,8 @@ omega = np.linspace(0, np.pi, 121)  # frequencies for spectral plot
 
 def app_model_parameter(label, base_value, scen_value): # to make input parameter
     txt = html.Th(label)
-    param1 = html.Th(dcc.Input(id='base_' + label, type='text', value=base_value, size=10))
-    param2 = html.Th(dcc.Input(id='scen_' + label, type='text', value=scen_value, size=10))
+    param1 = html.Th(dcc.Input(id='base_' + label, type='text', value=base_value, size='10'))
+    param2 = html.Th(dcc.Input(id='scen_' + label, type='text', value=scen_value, size='10'))
     return html.Tr([txt, param1, param2])
 
 
@@ -161,7 +161,7 @@ app.layout = html.Div(children=[
                        html.Hr(),
                        html.H4("Figure parameter"),
                        html.Table(children=[
-                           html.Tr([html.Th('Number of periods'), dcc.Input(id='horizon', type='text', value=60, size=10)])]
+                           html.Tr([html.Th('Number of periods'), dcc.Input(id='horizon', type='text', value=60, size='10')])]
                        ),
                        html.Button('PLOT', id='execute',style={'textAlign': 'center', 'backgroundColor': colors['buttons']}),
                        html.P('Solow-Swan-DEMO', style={'textAlign': 'center', 'color': colors['text'],'marginTop':250}),
